==> haskell-list-t-1.0.5.5-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.5
visibility:           public
id:                   list-t-1.0.5.5-J4c4e8jwAZ4BaLvuWZs01T
key:                  list-t-1.0.5.5-J4c4e8jwAZ4BaLvuWZs01T
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  9f26b0c3422688ff260c7878b4620e16
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.5-J4c4e8jwAZ4BaLvuWZs01T
depends:
    base-4.17.2.1 foldl-1.4.17-5FYRumVAObdFplp3GsUjBE
    logict-0.7.1.0-GwXyMxqvqDHKoFcBRhqDz3
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    monad-control-1.0.3.1-2ox58PDyrrF9r8TgoOtkMn mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-4mAULAIhjKjG98g1VZHGsY

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-list-t-1.0.5.5-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.5
visibility:           public
id:                   list-t-1.0.5.5-8lXUI1ymNIM7UUyeY3sOQP
key:                  list-t-1.0.5.5-8lXUI1ymNIM7UUyeY3sOQP
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  6c4b434993e54c88f7d0358c8235a21d
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.5-8lXUI1ymNIM7UUyeY3sOQP
depends:
    base-4.17.2.1 foldl-1.4.17-3P6kdqoRovmCVgbMOc5ZE
    logict-0.7.1.0-GwXyMxqvqDHKoFcBRhqDz3
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    monad-control-1.0.3.1-2ox58PDyrrF9r8TgoOtkMn mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-4mAULAIhjKjG98g1VZHGsY

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
